# utils

This repository contains various utility modules shared amongst several projects in the 4DN-DCIC. It is meant to be used internally by the DCIC team and externally as a Python API to [Fourfront](https://data.4dnucleome.org), the 4DN data portal.

pip installable as the `dcicutils` package with: `pip install dcicutils`

See [this document](./docs/getting_started.md) for tips on getting started. [Go here](./docs/examples.md) for examples of some of the most useful functions.

[![Build Status](https://travis-ci.org/4dn-dcic/utils.svg?branch=master)](https://travis-ci.org/4dn-dcic/utils)
[![Coverage](https://coveralls.io/repos/github/4dn-dcic/utils/badge.svg?branch=master)](https://coveralls.io/github/4dn-dcic/utils?branch=master)
